@@ -3,7 +3,7 @@
 
 import numpy as np
 import pandas as pd
-import warnings
+
 
 from math import ceil, floor, cos, radians
 from typing import Union, List, Tuple
@@ -18,21 +18,26 @@ from plotly.subplots import make_subplots
 
 from ._to_dataframe import dataframe, Frequency, MONTHS
 from ._helper import discontinuous_to_continuous, rgb_to_hex, ColorSet, color_set,\
-    mesh_to_coordinates
+    get_monthly_values, group_monthly
+from ._helper_chart import get_dummy_trace
 from ._psych import _psych_chart
 from .utils import Strategy, StrategyParameters
 
 from ladybug.datacollection import HourlyContinuousCollection, \
-    HourlyDiscontinuousCollection, MonthlyCollection, DailyCollection, BaseCollection
+    HourlyDiscontinuousCollection, MonthlyCollection, DailyCollection, BaseCollection,\
+    MonthlyPerHourCollection
 from ladybug.windrose import WindRose
+from ladybug.analysisperiod import AnalysisPeriod
 from ladybug.color import Color, Colorset, ColorRange
 from ladybug_pandas.series import Series
-from ladybug import psychrometrics as psy
 from ladybug.sunpath import Sunpath
 from ladybug.psychchart import PsychrometricChart
 from ladybug.dt import DateTime
 from ladybug_comfort.chart.polygonpmv import PolygonPMV
-from ladybug_geometry.geometry2d.pointvector import Point2D
+from ladybug.psychrometrics import wet_bulb_from_db_rh
+from ladybug.datatype.temperature import WetBulbTemperature
+
+from ladybug.epw import EPW
 
 
 # set white background in all charts
@@ -57,7 +62,7 @@ def heat_map(hourly_data: Union[HourlyContinuousCollection, HourlyDiscontinuousC
             of the data will be used. Defaults to None.
         show_title: A boolean to show or hide the title of the chart. Defaults to False.
         num_labels: The number of labels to be used in the legend. Defaults to None.
-        labels: A list of floats to be used as labels for the legend. Defaults to None. 
+        labels: A list of floats to be used as labels for the legend. Defaults to None.
 
     Returns:
         A plotly figure.
@@ -287,6 +292,9 @@ def bar_chart(data: Union[List[MonthlyCollection], List[DailyCollection]],
                 f'Title is set to "{title}" but show_title is set to False.')
         fig_title = None
 
+    # move legend upwards as mode data is loaded
+    legend_height = 1.2 if len(data) <= 3 else 1.2 + (len(data)-3)/10
+
     fig.update_layout(
         barmode='relative' if stack else 'group',
         template='plotly_white',
@@ -295,7 +303,7 @@ def bar_chart(data: Union[List[MonthlyCollection], List[DailyCollection]],
         title=fig_title,
         legend={
             'x': 0,
-            'y': 1.2,
+            'y': legend_height,
         }
     )
     fig.update_xaxes(dtick="M1", tickformat="%b", ticklabelmode="period",
@@ -416,13 +424,17 @@ def daily_bar_chart(data: DailyCollection,
     return _bar_chart_single_data(data, 'daily', title, show_title, color)
 
 
-def hourly_line_chart(data: HourlyContinuousCollection, color: Color = None) -> Figure:
+def hourly_line_chart(data: HourlyContinuousCollection, color: Color = None,
+                      title: str = None, show_title: bool = False) -> Figure:
     """Create a plotly line chart figure from a ladybug hourly continuous data object.
 
     Args:
         data: A ladybug HourlyContinuousCollection object.
         color: A Ladybug color object. If not set, a random color will be used. Defaults
             to None.
+        title: A string to be used as the title of the plot. Defaults to None.
+        show_title: A boolean to determine whether to show the title of the plot.
+            Defaults to False.
 
     Returns:
         A plotly figure.
@@ -497,6 +509,21 @@ def hourly_line_chart(data: HourlyContinuousCollection, color: Color = None) ->
             l=20, r=20, t=33, b=20))
     )
 
+    # setting the title for the figure
+    if show_title:
+        fig_title = {
+            'text': title if title else var,
+            'y': 1,
+            'x': 0.5,
+            'xanchor': 'center',
+            'yanchor': 'top'
+        }
+    else:
+        if title:
+            raise ValueError(
+                f'Title is set to "{title}" but show_title is set to False.')
+        fig_title = None
+
     fig.update_xaxes(
         dtick="M1",
         tickformat="%b",
@@ -518,15 +545,16 @@ def hourly_line_chart(data: HourlyContinuousCollection, color: Color = None) ->
     fig.update_layout(
         legend=dict(orientation="h", yanchor="bottom", y=1.02, xanchor="right", x=1),
         template='plotly_white',
+        title=fig_title
     )
 
     return fig
 
 
-def per_hour_line_chart(data: HourlyContinuousCollection, title: str = None,
-                        show_title: bool = False,
-                        color: Color = None) -> Figure:
-    """Create a plotly per hour line chart figure from a ladybug hourly continuous data.
+def diurnal_average_chart_from_hourly(data: HourlyContinuousCollection, title: str = None,
+                                      show_title: bool = False,
+                                      color: Color = None) -> Figure:
+    """Create a diurnal average chart from a ladybug hourly continuous data.
 
     Args:
         data: A ladybug HourlyContinuousCollection object.
@@ -543,83 +571,86 @@ def per_hour_line_chart(data: HourlyContinuousCollection, title: str = None,
     assert isinstance(data, HourlyContinuousCollection), 'Only ladybug hourly continuous'\
         f' data is supported. Instead got {type(data)}'
 
+    # get monthly per hour average data
+    monthly_values = get_monthly_values(data.average_monthly_per_hour())
+    monthly_lower_values = get_monthly_values(data.percentile_monthly_per_hour(0))
+    monthly_higher_values = get_monthly_values(data.percentile_monthly_per_hour(100))
+
     var = data.header.data_type.name
     var_unit = data.header.unit
     var_color = color if color else Color(
         randint(0, 255), randint(0, 255), randint(0, 255))
+    var_color = rgb_to_hex(var_color)
+    range_y = [data.min, data.max]
 
-    df = dataframe()
-    series = Series(data)
-    df[var] = series.values
-
-    data_max = 5 * ceil(df[var].max() / 5)
-    data_min = 5 * floor(df[var].min() / 5)
-    range_y = [data_min, data_max]
-
-    var_month_ave = df.groupby(["month", "hour"])[var].median().reset_index()
-
-    fig = make_subplots(
-        rows=1,
-        cols=12,
-        subplot_titles=MONTHS,
-    )
+    fig = go.Figure()
 
     for i in range(12):
+        x = [[MONTHS[i]]*24, list(range(0, 24))]
 
+        # add lower range
         fig.add_trace(
             go.Scatter(
-                x=df.loc[df["month"] == i + 1, "hour"],
-                y=df.loc[df["month"] == i + 1, var],
-                mode="markers",
-                marker_color=rgb_to_hex(var_color),
-                opacity=0.5,
-                marker_size=3,
-                name=MONTHS[i],
+                x=x,
+                y=monthly_lower_values[i],
+                line_color=var_color,
+                line_width=0,
+                opacity=0.2,
+                showlegend=False,
+                hovertemplate=(
+                    "<b>"
+                    + var+' low'
+                    + ": %{y:.2f} "
+                    + var_unit
+                    + "</b><br>Month: %{x[0]}<br>Hour: %{x[1]}:00<br>"
+                    + "<extra></extra>"
+                ),
+            )
+        )
+
+        # add higher range
+        fig.add_trace(
+            go.Scatter(
+                x=x,
+                y=monthly_higher_values[i],
+                line_color=var_color,
+                fill='tonexty',
+                line_width=0,
+                opacity=0.1,
+                showlegend=False,
+                hovertemplate=(
+                    "<b>"
+                    + var + ' high'
+                    + ": %{y:.2f} "
+                    + var_unit
+                    + "</b><br>Month: %{x[0]}<br>Hour: %{x[1]}:00<br>"
+                    + "<extra></extra>"
+                ),)
+        )
+
+        # add MonthlyPerHour average dry-bulb temperature
+        fig.add_trace(
+            go.Scatter(
+                x=x,
+                y=monthly_values[i],
+                line_color=var_color,
+                line_width=2,
                 showlegend=False,
-                customdata=df.loc[df["month"] == i + 1, "month_names"],
                 hovertemplate=(
                     "<b>"
                     + var
                     + ": %{y:.2f} "
                     + var_unit
-                    + "</b><br>Month: %{customdata}<br>Hour: %{x}:00<br>"
-                ),
-            ),
-            row=1,
-            col=i + 1,
+                    + "</b><br>Month: %{x[0]}<br>Hour: %{x[1]}:00<br>"
+                    + "<extra></extra>"
+                ))
         )
 
-        fig.add_trace(
-            go.Scatter(
-                x=var_month_ave.loc[var_month_ave["month"] == i + 1, "hour"],
-                y=var_month_ave.loc[var_month_ave["month"] == i + 1, var],
-                mode="lines",
-                line_color=rgb_to_hex(var_color),
-                line_width=3,
-                name=None,
-                showlegend=False,
-                hovertemplate=(
-                    "<b>" + var + ": %{y:.2f} " + var_unit + "</b><br>Hour: %{x}:00<br>"
-                ),
-            ),
-            row=1,
-            col=i + 1,
-        )
-
-        fig.update_xaxes(range=[0, 25], row=1, col=i + 1)
-        fig.update_yaxes(range=range_y, row=1, col=i + 1)
-
-    fig.update_xaxes(
-        ticktext=["6", "12", "18"], tickvals=["6", "12", "18"], tickangle=0
-    )
-
-    chart_title = title if title else var + f' ({var_unit})'
-
     # setting the title for the figure
     if show_title:
         fig_title = {
-            'text': chart_title,
-            'y': 1,
+            'text': title if title else var + f' ({var_unit})',
+            'y': 0.85,
             'x': 0.5,
             'xanchor': 'center',
             'yanchor': 'top'
@@ -631,10 +662,295 @@ def per_hour_line_chart(data: HourlyContinuousCollection, title: str = None,
         fig_title = None
 
     fig.update_layout(
-        template='plotly_white',
-        dragmode=False,
-        margin=dict(l=20, r=20, t=55, b=20),
-        title=fig_title
+
+        xaxis=dict(
+            showdividers=False,
+            showline=True,
+            linecolor='black',
+            linewidth=1,
+            ticks='outside',
+            tickson='boundaries',
+            tickwidth=1,
+            ticklen=5),
+
+        yaxis=dict(
+            showline=True,
+            linecolor='black',
+            linewidth=1,
+            title=var_unit),
+
+        title=fig_title,
+
+    )
+    return fig
+
+
+def diurnal_average_chart(epw: EPW, title: str = None, show_title: bool = False,
+                          colors: Union[List[Color], Tuple[Color]] = Colorset.original()) -> Figure:
+    """Create a diurnal average chart from a ladybug EPW object.
+
+    Args:
+        epw: A ladybug EPW object.
+        title: A string to be used as the title of the plot. Defaults to None.
+        show_title: A boolean to determine whether to show the title of the plot.
+            Defaults to False.
+        colorset: A ColorSet object. Defaults to ColorSet.original.
+
+    Returns:
+        A plotly figure.
+    """
+
+    # reset colors if length of colors is less than 5
+    if len(colors) < 5:
+        color_range = ColorRange(colors, domain=[0, 5])
+        num_of_colors: int = len(colors)*2 if len(colors)*2 >= 5 else 5
+        colors: List[Color] = [color_range.color(i) for i in range(num_of_colors)]
+
+    dbt_color = rgb_to_hex(colors[-1])
+    wbt_color = rgb_to_hex(colors[-2])
+    glob_hor_rad_color = rgb_to_hex(colors[-3])
+    dir_nor_rad_color = rgb_to_hex(colors[-4])
+    diff_hor_rad_color = rgb_to_hex(colors[-5])
+    spread_color = rgb_to_hex(Color(149, 152, 156))
+
+    # get monthly per hour average data
+    glob_hor_rad = get_monthly_values(
+        epw.global_horizontal_radiation.average_monthly_per_hour())
+
+    dir_nor_rad = get_monthly_values(
+        epw.direct_normal_radiation.average_monthly_per_hour())
+
+    diff_hor_rad = get_monthly_values(
+        epw.diffuse_horizontal_radiation.average_monthly_per_hour())
+
+    dry_bulb_temp = get_monthly_values(
+        epw.dry_bulb_temperature.average_monthly_per_hour())
+
+    dry_bulb_temp_low = get_monthly_values(
+        epw.dry_bulb_temperature.percentile_monthly_per_hour(0))
+
+    dry_bulb_temp_high = get_monthly_values(
+        epw.dry_bulb_temperature.percentile_monthly_per_hour(100))
+
+    wet_bulb = HourlyContinuousCollection.compute_function_aligned(
+        wet_bulb_from_db_rh, [epw.dry_bulb_temperature,
+                              epw.relative_humidity, epw.atmospheric_station_pressure],
+        WetBulbTemperature(), 'C')
+    wet_bulb_temp = get_monthly_values(wet_bulb.average_monthly_per_hour())
+
+    fig = go.Figure()
+
+    for i in range(12):
+        x = [[MONTHS[i]]*24, list(range(0, 24))]
+
+        # add lower dry-bulb temperature
+        fig.add_trace(
+            go.Scatter(
+                x=x,
+                y=dry_bulb_temp_low[i],
+                line_color=spread_color,
+                line_width=0,
+                opacity=0.2,
+                yaxis='y2',
+                showlegend=False,
+                hovertemplate=(
+                    "<b>"
+                    + 'Dry-bulb temperature low'
+                    + ": %{y:.2f} "
+                    + 'C'
+                    + "</b><br>Month: %{x[0]}<br>Hour: %{x[1]}:00<br>"
+                    + "<extra></extra>"
+                ),
+            )
+        )
+
+        # add higher dry-bulb temperature
+        fig.add_trace(
+            go.Scatter(
+                x=x,
+                y=dry_bulb_temp_high[i],
+                line_color=spread_color,
+                fill='tonexty',
+                line_width=0,
+                opacity=0.1,
+                yaxis='y2',
+                showlegend=False,
+                hovertemplate=(
+                    "<b>"
+                    + 'Dry-bulb temperature high'
+                    + ": %{y:.2f} "
+                    + 'C'
+                    + "</b><br>Month: %{x[0]}<br>Hour: %{x[1]}:00<br>"
+                    + "<extra></extra>"
+                ),)
+        )
+
+        # add global horizontal radiation
+        fig.add_trace(
+            go.Scatter(
+                x=x,
+                y=glob_hor_rad[i],
+                fill='tozeroy',
+                line_width=1,
+                line_color=glob_hor_rad_color,
+                yaxis='y',
+                showlegend=False,
+                hovertemplate=(
+                    "<b>"
+                    + 'Monthly per hour average Global horizontal radiation'
+                    + ": %{y:.2f} "
+                    + 'Wh/m2'
+                    + "</b><br>Month: %{x[0]}<br>Hour: %{x[1]}:00<br>"
+                    + "<extra></extra>"
+                ))
+        )
+
+        # add direct normal radiation
+        fig.add_trace(
+            go.Scatter(
+                x=x,
+                y=dir_nor_rad[i],
+                fill='tozeroy',
+                line_width=1,
+                line_color=dir_nor_rad_color,
+                yaxis='y',
+                showlegend=False,
+                hovertemplate=(
+                    "<b>"
+                    + 'Monthly per hour average Direct normal radiation'
+                    + ": %{y:.2f} "
+                    + 'Wh/m2'
+                    + "</b><br>Month: %{x[0]}<br>Hour: %{x[1]}:00<br>"
+                    + "<extra></extra>"
+                ))
+        )
+
+        # add diffuse horizontal radiation
+        fig.add_trace(
+            go.Scatter(
+                x=x,
+                y=diff_hor_rad[i],
+                fill='tozeroy',
+                line_width=1,
+                line_color=diff_hor_rad_color,
+                yaxis='y',
+                showlegend=False,
+                hovertemplate=(
+                    "<b>"
+                    + 'Monthly per hour average Diffused horizontal radiation'
+                    + ": %{y:.2f} "
+                    + 'Wh/m2'
+                    + "</b><br>Month: %{x[0]}<br>Hour: %{x[1]}:00<br>"
+                    + "<extra></extra>"
+                ))
+        )
+
+        # add MonthlyPerHour average dry-bulb temperature
+        fig.add_trace(
+            go.Scatter(
+                x=x,
+                y=dry_bulb_temp[i],
+                line_color=dbt_color,
+                line_width=2,
+                yaxis='y2',
+                showlegend=False,
+                hovertemplate=(
+                    "<b>"
+                    + 'Monthly per hour average dry-bulb temperature'
+                    + ": %{y:.2f} "
+                    + 'C'
+                    + "</b><br>Month: %{x[0]}<br>Hour: %{x[1]}:00<br>"
+                    + "<extra></extra>"
+                ))
+        )
+
+        # add MonthlyPerHour average wet-bulb temperature
+        fig.add_trace(
+            go.Scatter(
+                x=x,
+                y=wet_bulb_temp[i],
+                line_color=wbt_color,
+                line_width=2,
+                yaxis='y2',
+                showlegend=False,
+                hovertemplate=(
+                    "<b>"
+                    + 'Monthly per hour average wet-bulb temperature'
+                    + ": %{y:.2f} "
+                    + 'C'
+                    + "</b><br>Month: %{x[0]}<br>Hour: %{x[1]}:00<br>"
+                    + "<extra></extra>"
+                ))
+        )
+
+    # Add dummy traces to create legend
+    fig.add_trace(get_dummy_trace(
+        'Diffused horizontal radiation', diff_hor_rad_color))
+    fig.add_trace(get_dummy_trace(
+        'Direct normal radiation', dir_nor_rad_color))
+    fig.add_trace(get_dummy_trace(
+        'Global horizontal radiation', glob_hor_rad_color))
+    fig.add_trace(get_dummy_trace(
+        'Wet-bulb temperature', wbt_color))
+    fig.add_trace(get_dummy_trace(
+        'Dry-bulb temperature', dbt_color))
+
+    # setting the title for the figure
+    if show_title:
+        fig_title = {
+            'text': title if title else 'Diurnal Average',
+            'y': 0.95,
+            'x': 0.5,
+            'xanchor': 'center',
+            'yanchor': 'top'
+        }
+    else:
+        if title:
+            raise ValueError(
+                f'Title is set to "{title}" but show_title is set to False.')
+        fig_title = None
+
+    fig.update_layout(
+
+        xaxis=dict(
+            showdividers=False,
+            showline=True,
+            linecolor='black',
+            linewidth=1,
+            ticks='outside',
+            tickson='boundaries',
+            tickwidth=1,
+            ticklen=5),
+
+        yaxis=dict(
+            range=[0, 1600],
+            tick0=0,
+            dtick=100,
+            title='Radiation Wh/m2',
+            showline=True,
+            linecolor='black',
+            linewidth=1),
+
+        yaxis2=dict(
+            range=[-20, 60],
+            tick0=-20,
+            dtick=5,
+            title='Temperature C',
+            overlaying='y',
+            side='right',
+            showline=True,
+            linecolor='black',
+            linewidth=1),
+
+        title=fig_title,
+        legend=dict(
+            orientation="h",
+            yanchor="bottom",
+            y=1.02,
+            xanchor="right",
+            x=1
+        )
+
     )
 
     return fig
@@ -665,8 +981,8 @@ def wind_rose(wind_rose: WindRose, title: str = None, show_title: bool = False)
         A plotly figure.
     """
 
-    assert isinstance(wind_rose, WindRose), 'Ladybug WindRose object is required.'\
-        f' Instead got {type(wind_rose)}'
+    assert isinstance(wind_rose, WindRose), 'Ladybug WindRose object is required.'
+    f' Instead got {type(wind_rose)}'
 
     wind_speed = wind_rose.analysis_data_collection
     wind_dir = wind_rose.direction_data_collection
@@ -969,7 +1285,7 @@ def sunpath(sunpath: Sunpath, data: HourlyContinuousCollection = None,
                     colorscale=var_colorscale,
                     cmin=var_range[0],
                     cmax=var_range[1],
-                    colorbar=dict(thickness=30, title=var_unit + "<br>  "),
+                    colorbar=dict(thickness=10, title=var_unit + "<br>  "),
                 ),
                 customdata=np.stack(
                     (
@@ -1119,3 +1435,105 @@ def sunpath(sunpath: Sunpath, data: HourlyContinuousCollection = None,
     )
 
     return fig
+
+
+def bar_chart_with_table(data: List[MonthlyCollection],
+                         min_range: float = None, max_range: float = None,
+                         colors: List[Color] = None,
+                         title: str = None,
+                         show_title: bool = False,
+                         stack: bool = False) -> Figure:
+    """Create a plotly bar chart figure from multiple ladybug monthly or daily data.
+
+    Args:
+        data: A list of ladybug monthly data.
+        min_range: Minimum value for the legend. If not set will be calculated
+            from the data. Defaults to None.
+        max_range: Maximum value for the legend. If not set will be calculated
+            from the data. Defaults to None.
+        colors: A list of ladybug color objects. The length of this list needs to match
+            the length of data argument. If not set, random colors will be used.
+            Defaults to None.
+        title: A string to be used as the title of the plot. If not set, the
+            names of data will be used to create a title for the chart. Defaults to None.
+        show_title: A boolean to set whether to show the title of the chart.
+            Defaults to False.
+        stack: A boolean to determine whether to stack the data. Defaults to False which
+            will show data side by side.
+
+    Returns:
+        A plotly figure.
+    """
+    assert len(data) > 0 and all([isinstance(item, MonthlyCollection)
+                                  for item in data]), 'Only a list of ladybug '\
+        f' monthly data is supported. Instead got {type(data)}'
+
+    if colors:
+        assert len(colors) == len(data), 'Length of colors argument needs to match'\
+            f' the length of data argument. Instead got {len(colors)} and {len(data)}'
+
+    colors = colors if colors else [Color(randint(0, 255), randint(0, 255),
+                                          randint(0, 255)) for item in data]
+
+    # set the range of y-axis if provided
+    if min_range == None and max_range == None:
+        y_range = None
+    elif min_range != None and max_range != None:
+        y_range = [min_range, max_range]
+
+    fig = make_subplots(rows=2, cols=1, vertical_spacing=0.1, specs=[[{"type": "bar"}],
+                                                                     [{"type": "table"}]])
+
+    names = []
+
+    for count, item in enumerate(data):
+        var = item.header.data_type.name
+        var_unit = item.header.unit
+        color = colors[count] if colors else None
+        bar = _monthly_bar(item, var, var_unit, color)
+        fig.add_trace(bar, row=1, col=1)
+        names.append(var)
+
+    # add table
+    values, colors = group_monthly(data, colors)
+    table = go.Table(
+        header=dict(values=None, fill_color='#ffffff'),
+        cells=dict(values=values, fill_color=colors))
+
+    fig.add_trace(table, row=2, col=1)
+
+    # setting the title for the figure
+    if show_title:
+        fig_title = {
+            'text': title if title else ' - '.join(names),
+            'y': 1,
+            'x': 0.5,
+            'xanchor': 'center',
+            'yanchor': 'top'
+        }
+    else:
+        if title:
+            raise ValueError(
+                f'Title is set to "{title}" but show_title is set to False.')
+        fig_title = None
+
+    # move legend upwards as mode data is loaded
+    legend_height = 1.2 if len(data) <= 3 else 1.2 + (len(data)-3)/10
+
+    fig.update_layout(
+        barmode='relative' if stack else 'group',
+        template='plotly_white',
+        margin=dict(l=20, r=20, t=33, b=20),
+        yaxis_nticks=13,
+        title=fig_title,
+        legend={
+            'x': 0,
+            'y': legend_height,
+        }
+    )
+    fig.update_xaxes(dtick="M1", tickformat="%b", ticklabelmode="period",
+                     showline=True, linewidth=1, linecolor="black", mirror=True)
+    fig.update_yaxes(showline=True, linewidth=1,
+                     linecolor="black", mirror=True, range=y_range)
+
+    return fig
