@@ -2,7 +2,7 @@ from plotly.graph_objects import Figure
 from ladybug_comfort.degreetime import heating_degree_time, cooling_degree_time
 from ladybug.datacollection import HourlyContinuousCollection
 from ladybug.datatype.temperaturetime import HeatingDegreeTime, CoolingDegreeTime
-from ladybug_charts.to_figure import bar_chart
+from ladybug_charts.to_figure import bar_chart, bar_chart_with_table
 from ladybug_charts.utils import Strategy
 from ladybug.color import Color, Colorset
 from ladybug.windrose import WindRose
@@ -12,6 +12,8 @@ from ladybug.monthlychart import MonthlyChart
 from ladybug.sunpath import Sunpath
 from ladybug_comfort.chart.polygonpmv import PolygonPMV
 
+# heat maps
+
 
 def test_hourly_continuous_to_heatmap(epw):
     fig = epw.dry_bulb_temperature.heat_map()
@@ -22,15 +24,7 @@ def test_hourly_discontinuous_to_heatmap(epw):
     fig = epw.dry_bulb_temperature.filter_by_conditional_statement('a>25').heat_map()
     assert isinstance(fig, Figure)
 
-
-def test_hourly_to_per_hour_chart(epw):
-    fig = epw.dry_bulb_temperature.per_hour_line_chart()
-    assert isinstance(fig, Figure)
-
-
-def test_hourly_to_line_chart(epw):
-    fig = epw.dry_bulb_temperature.line_chart()
-    assert isinstance(fig, Figure)
+# bar charts
 
 
 def test_monthly_to_bar_chart(epw):
@@ -72,6 +66,25 @@ def test_bar_chart_multiple_daily_data(epw):
     fig = bar_chart([dbt, rh])
     assert isinstance(fig, Figure)
 
+# line-chart
+
+
+def test_hourly_to_line_chart(epw):
+    fig = epw.dry_bulb_temperature.line_chart()
+    assert isinstance(fig, Figure)
+
+# diurnal-average-charts
+
+
+def test_hourly_to_diurnal_average(epw):
+    fig = epw.dry_bulb_temperature.diurnal_average_chart()
+    assert isinstance(fig, Figure)
+
+
+def test_epw_to_diurnal_average(epw):
+    fig = epw.diurnal_average_chart()
+    assert isinstance(fig, Figure)
+
 
 def test_hourly_plot(epw):
     hp = HourlyPlot(epw.dry_bulb_temperature)
@@ -119,3 +132,15 @@ def test_sunpath(epw):
     fig = lb_sunpath.plot(data=epw.dry_bulb_temperature, colorset=Colorset.nuanced(),
                           min_range=0, max_range=50, title='SUNPATH', show_title=True)
     assert isinstance(fig, Figure)
+
+
+def test_bar_charts_with_table(epw):
+
+    dir = epw.direct_normal_radiation.average_monthly()
+    diff = epw.diffuse_horizontal_radiation.average_monthly()
+    glob = epw.global_horizontal_radiation.average_monthly()
+
+    colors = [Color(255, 79, 56), Color(255, 139, 56), Color(255, 199, 56)]
+    fig = bar_chart_with_table(data=[dir, diff, glob],
+                               colors=colors, stack=True)
+    assert isinstance(fig, Figure)
